==> haskell-conduit-extra-1.3.0-62-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-conduit-extra.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: conduit-extra
version: 1.3.0
id: conduit-extra-1.3.0-Ao8kRXZorHj2LZSVU88NWN
key: conduit-extra-1.3.0-Ao8kRXZorHj2LZSVU88NWN
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: http://github.com/snoyberg/conduit
synopsis: Batteries included conduit: adapters for common libraries.
description:
    The conduit package itself maintains relative small dependencies. The purpose of this package is to collect commonly used utility functions wrapping other library dependencies, without depending on heavier-weight dependencies. The basic idea is that this package should only depend on haskell-platform packages and conduit.
category: Data, Conduit
abi: 7ad1c551e9ebc6ed0d6ad52f692658be
exposed: True
exposed-modules:
    Data.Conduit.Attoparsec Data.Conduit.Binary
    Data.Conduit.ByteString.Builder Data.Conduit.Filesystem
    Data.Conduit.Foldl Data.Conduit.Lazy Data.Conduit.Network
    Data.Conduit.Network.UDP Data.Conduit.Network.Unix
    Data.Conduit.Process Data.Conduit.Process.Typed Data.Conduit.Text
    Data.Conduit.Zlib
import-dirs: /usr/lib/ghc-8.4.3/site-local/conduit-extra-1.3.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/conduit-extra-1.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/conduit-extra-1.3.0
hs-libraries: HSconduit-extra-1.3.0-Ao8kRXZorHj2LZSVU88NWN
depends:
    base-4.11.1.0 conduit-1.3.0.3-3atYUnJcrfzHiVZ1ljsUyz
    bytestring-0.10.8.2 text-1.2.3.0 transformers-0.5.5.0
    async-2.2.1-B6m2kYywRJu7nicgTBxsJe
    attoparsec-0.13.2.2-8we02vABEtHGk2BnvIppYV directory-1.3.1.5
    filepath-1.4.2 network-2.7.0.2-LgHK7D01MTj1Jd51bZLfR6
    primitive-0.6.4.0-39Pwmm1zkQX6bM7xFUT3Jc process-1.6.3.0
    resourcet-1.2.1-90e8KTtIFtW4uIipYnIL1W stm-2.4.5.0
    streaming-commons-0.2.1.0-KukphjZfr9lAsNmlsFtHsx
    unliftio-core-0.1.2.0-900TPot3SR34dceIcVaslS
    typed-process-0.2.3.0-ImFRzhowhg4nw132K6qzK
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             conduit-1.3.0.3-3atYUnJcrfzHiVZ1ljsUyz=636a5a0c86469573aa6778bb72b6971c
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             async-2.2.1-B6m2kYywRJu7nicgTBxsJe=32776142fda961cc693aa4db742773f9
             attoparsec-0.13.2.2-8we02vABEtHGk2BnvIppYV=c37e9b7162f4a40359d5b1d46155434d
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             network-2.7.0.2-LgHK7D01MTj1Jd51bZLfR6=330c7805fe7a28a7f81311ba9bcc7e3f
             primitive-0.6.4.0-39Pwmm1zkQX6bM7xFUT3Jc=0a8d9e3ca28de3a4ac62e5f0044fa23c
             process-1.6.3.0=b58285e21ceee9f67d7be28ddb8b2627
             resourcet-1.2.1-90e8KTtIFtW4uIipYnIL1W=47912d2f8f0c41e14474b51aa0093f3e
             stm-2.4.5.0=4e743cb5a370ac3fbade528432951c3f
             streaming-commons-0.2.1.0-KukphjZfr9lAsNmlsFtHsx=f7c36bdaa0604535382886173e3c6ef9
             unliftio-core-0.1.2.0-900TPot3SR34dceIcVaslS=b3bd63f18add30d59629e9599623cc96
             typed-process-0.2.3.0-ImFRzhowhg4nw132K6qzK=0b98ba53f532b5b4711d20440d35cb8c
haddock-interfaces: /usr/share/doc/haskell-conduit-extra/html/conduit-extra.haddock
haddock-html: /usr/share/doc/haskell-conduit-extra/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-conduit-extra-1.3.0-66-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-conduit-extra.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: conduit-extra
version: 1.3.0
id: conduit-extra-1.3.0-IvSUWo240ze2GEigZ33WNv
key: conduit-extra-1.3.0-IvSUWo240ze2GEigZ33WNv
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: http://github.com/snoyberg/conduit
synopsis: Batteries included conduit: adapters for common libraries.
description:
    The conduit package itself maintains relative small dependencies. The purpose of this package is to collect commonly used utility functions wrapping other library dependencies, without depending on heavier-weight dependencies. The basic idea is that this package should only depend on haskell-platform packages and conduit.
category: Data, Conduit
abi: 19b7d756647f6b712d7a3abb6a1dcde9
exposed: True
exposed-modules:
    Data.Conduit.Attoparsec Data.Conduit.Binary
    Data.Conduit.ByteString.Builder Data.Conduit.Filesystem
    Data.Conduit.Foldl Data.Conduit.Lazy Data.Conduit.Network
    Data.Conduit.Network.UDP Data.Conduit.Network.Unix
    Data.Conduit.Process Data.Conduit.Process.Typed Data.Conduit.Text
    Data.Conduit.Zlib
import-dirs: /usr/lib/ghc-8.4.3/site-local/conduit-extra-1.3.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/conduit-extra-1.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/conduit-extra-1.3.0
hs-libraries: HSconduit-extra-1.3.0-IvSUWo240ze2GEigZ33WNv
depends:
    base-4.11.1.0 conduit-1.3.1-D4o2a9oWO4x5dWaRtT4EJt
    bytestring-0.10.8.2 text-1.2.3.0 transformers-0.5.5.0
    async-2.2.1-B6m2kYywRJu7nicgTBxsJe
    attoparsec-0.13.2.2-9h5IhQcJmGG8LaxEVphKNH directory-1.3.1.5
    filepath-1.4.2 network-2.7.0.2-6VFNTYcbIFUHazSUdvqi9O
    primitive-0.6.4.0-39Pwmm1zkQX6bM7xFUT3Jc process-1.6.3.0
    resourcet-1.2.2-6DzJC8xJzODJ5bfjxaarAo stm-2.4.5.0
    streaming-commons-0.2.1.0-Gpxpub25JmP71C5zyBo1QO
    unliftio-core-0.1.2.0-900TPot3SR34dceIcVaslS
    typed-process-0.2.3.0-CDOFlczjabVDQQGzoaCTh9
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             conduit-1.3.1-D4o2a9oWO4x5dWaRtT4EJt=57a4ce950f9daf9d0cdf932d7abba0ef
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             async-2.2.1-B6m2kYywRJu7nicgTBxsJe=32776142fda961cc693aa4db742773f9
             attoparsec-0.13.2.2-9h5IhQcJmGG8LaxEVphKNH=a6266481de32b74ad34bda9cb8283f99
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             network-2.7.0.2-6VFNTYcbIFUHazSUdvqi9O=fdb582ab967eb93afe5e0be3b51f9140
             primitive-0.6.4.0-39Pwmm1zkQX6bM7xFUT3Jc=0a8d9e3ca28de3a4ac62e5f0044fa23c
             process-1.6.3.0=b58285e21ceee9f67d7be28ddb8b2627
             resourcet-1.2.2-6DzJC8xJzODJ5bfjxaarAo=f3a4f434b6add96b232537b442507397
             stm-2.4.5.0=4e743cb5a370ac3fbade528432951c3f
             streaming-commons-0.2.1.0-Gpxpub25JmP71C5zyBo1QO=bc2d13db44c70f12d690625ad432fd89
             unliftio-core-0.1.2.0-900TPot3SR34dceIcVaslS=b3bd63f18add30d59629e9599623cc96
             typed-process-0.2.3.0-CDOFlczjabVDQQGzoaCTh9=0d4a876263ebbf2f9a12e090628a20ae
haddock-interfaces: /usr/share/doc/haskell-conduit-extra/html/conduit-extra.haddock
haddock-html: /usr/share/doc/haskell-conduit-extra/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
